@@ -1,26 +1,72 @@
+# If multiple checks can be done using the same response
+# then they should be done under a single test case.
+
 from datetime import datetime, timedelta
-from typing import List
 
-import requests
-
-from ..client import client
 from ..decorators import test_wrapper
 from ..exceptions import FailedTest
-from ..models import TestResult, ApiError
+from ..models import TestResult
 from ..utils import availability
-from ..utils.adapters import get_variants
-
-
-@test_wrapper
-def test_response_format(api_url, api_key, product_id, version=1):
-    '''[Variants] Checking response format'''
-    return availability.test_response_format(api_url, api_key, product_id, 'variants', get_variants, version=1)
 
 
 @test_wrapper
 def test_next_30_days(api_url, api_key, product_id, version=1):
-    '''[Variants] Checking for any availability in the next 30 days'''
-    return availability.test_next_30_days(api_url, api_key, product_id, 'variants', get_variants, version=1)
+    '''[Variants] Checking availability for the next 30 days'''
+    start_date = datetime.utcnow().date()
+    end_date = start_date + timedelta(days=30)
+    days, raw_response = availability.get_availability_variants(
+        api_url,
+        api_key,
+        product_id,
+        version,
+        start_date,
+        end_date,
+    )
+
+    # non-zero availability check
+    max_tickets_sum = sum(day.max_tickets for day in days)
+    if max_tickets_sum <= 0:
+        raise FailedTest(
+            message='There is no availability for next 30 days',
+            response=raw_response,
+        )
+
+    # variant IDs uniqueness
+    variant_ids = set()
+    variant_name_id_map = {}
+    variant_counter = 0
+    days_counter = 0
+    for day in days:
+        days_counter += 1
+        for variant in day.variants:
+            # checking if one variant name always have the same ID
+            if variant.name in variant_name_id_map:
+                if variant.id != variant_name_id_map[variant.name]:
+                    raise FailedTest(
+                        message=f'Variant {variant.name} should always have the same ID.',
+                        response=raw_response,
+                    )
+            else:
+                variant_name_id_map[variant.name] = variant.id
+
+            variant_counter += 1
+            variant_ids.add(variant.id)
+
+        # checking number of unique variants in timespan of 7 days
+        if days_counter == 7:
+            days_counter = 0
+            if len(variant_ids) > 20:
+                return TestResult(
+                    status=1,
+                    message=(
+                        'More then 20 unique variants were found in a timespan of 7 days. '
+                        'Make sure that this is not an error. Variants should not be unique for '
+                        'each day.'
+                    ),
+                )
+            variant_ids = set()
+
+    return TestResult()
 
 
 @test_wrapper
